/*
 * Draws a grid of greyscale squares, one per input.
 *
 * Use this to test your input board, putting inputs to +5V and GND.
 *
 * Also, it runs as fast as possible, so it kind of chews up the CPU.
 */

import processing.serial.*;

Serial myPort;

boolean draw_grid = true; // draw the grid?  If false, just measures speed.

// Data for Samples-per-second calculation
int frameno;
float t0;
String fps; 

void setup() 
{
  size(800, 600);

  String portName = Serial.list()[0];
  myPort = new Serial(this, portName, 115200);
  
  PFont font = loadFont("FreeSansBold-12.vlw");
  
  textFont(font);
  t0 = millis();
  
  frameno = 0;
  fps = "XXXX.X S/s";
}

 

void draw()
{
  String l = myPort.readStringUntil('\n');
 // print(l);

  if (l == null) { delay(10); return; } // wait for valid data
  
  int vals[] = int(split(l, ' '));
  if (vals.length < 48) { delay(10); return; } // throw out bogus lines
  
  frameno++;
  
  
  if (draw_grid) {
  for(int i = 0; i < 48; i++) {
    fill(255*vals[i]/1023.0);
    int x = i / 6;
    int y = i % 6;


    rect(x*100, y*100, 100, 100);
    
    fill(200, 200, 50);
    text(i%6 + "-" + i/6 + ": " + vals[i], x*100 + 20, y*100 + 20, 20);

  }
      fill(200, 200, 50); 
  text(fps, 720, 580, 30 );

  }


  if (frameno == 100) {
    float t1 = millis();
    float dt = t1-t0;

    float rate = (float)frameno*1000.0/dt;
    
    fps = nf(rate, 4,1) + " S/s";
    
    frameno = 0;
    t0 = millis();
    
    if (!draw_grid) {
      fill(0);
      rect(0,0, 200, 200);
      fill(255);
      text(fps, 50, 50, 1);
    }
  }
  
 // delay(5);  
}
